@@ -12,15 +12,16 @@ def heatclient():
 
         def __init__(self):
             stacks = [
-                Anon(stack_status="CREATE_COMPLETE", stack_name="overcloud",
+                # Anon(stack_status="CREATE_COMPLETE", stack_name="overcloud",
+                #    creation_time=datetime.now(), updated_time=None),
+                Anon(stack_status="CREATE_FAILED", stack_name="overcloud",
                      creation_time=datetime.now(), updated_time=None),
-                # Anon(stack_status="CREATE_FAILED", stack_name="overcloud"),
                 # Anon(stack_status="CREATE_IN", stack_name="overcloud"),
             ]
             self.stacks = Anon(list=lambda: stacks)
 
-            self.events = Anon(list=lambda **args: [])
-            self.resources = Anon(list=lambda **args: [])
+            self.events = Anon(list=lambda **kwargs: [])
+            self.resources = Anon(list=lambda *args, **kwargs: [])
 
     return HeatClient()
 
