@@ -50,4 +50,7 @@ def heat_event_log_formatter(events):
         }
         event_log.append(log)
 
-    return [urwid.Text(line) for line in event_log]
+    lines = [urwid.Text(line, wrap="clip") for line in event_log]
+    box = urwid.ListBox(urwid.SimpleListWalker(lines))
+    box.set_focus_valign('bottom')
+    return urwid.BoxAdapter(box, 20)
